<?php
defined('_JEXEC') or die;

/**
 * Template for Joomla! CMS, created with Artisteer.
 * See readme.txt for more details on how to use the template.
 */

require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'functions.php';

// Create alias for $this object reference:
$document = $this;

// Shortcut for template base url:
$templateUrl = $document->baseurl . '/templates/' . $document->template;

Artx::load("Artx_Page");

// Initialize $view:
$view = $this->artx = new ArtxPage($this);

// Decorate component with Artisteer style:
$view->componentWrapper();

JHtml::_('behavior.framework', true);

?>
<!DOCTYPE html>
<html dir="ltr" lang="<?php echo $document->language; ?>">
<head>
    <jdoc:include type="head" />
    <link rel="stylesheet" href="<?php echo $document->baseurl; ?>/templates/system/css/system.css" />
    <link rel="stylesheet" href="<?php echo $document->baseurl; ?>/templates/system/css/general.css" />

    <!-- Created by Artisteer v4.1.0.59782 -->
    
    
    <meta name="viewport" content="initial-scale = 1.0, maximum-scale = 1.0, user-scalable = no, width = device-width">

    <!--[if lt IE 9]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
    <link rel="stylesheet" href="<?php echo $templateUrl; ?>/css/template.css" media="screen">
    <!--[if lte IE 7]><link rel="stylesheet" href="<?php echo $templateUrl; ?>/css/template.ie7.css" media="screen" /><![endif]-->
    <link rel="stylesheet" href="<?php echo $templateUrl; ?>/css/template.responsive.css" media="all">
<link rel="stylesheet" type="text/css" href="http://fonts.googleapis.com/css?family=Rosarivo|Goudy+Bookletter+1911&amp;subset=latin">

    <script>if ('undefined' != typeof jQuery) document._artxJQueryBackup = jQuery;</script>
    <script src="<?php echo $templateUrl; ?>/jquery.js"></script>
    <script>jQuery.noConflict();</script>

    <script src="<?php echo $templateUrl; ?>/script.js"></script>
    <?php $view->includeInlineScripts() ?>
    <script>if (document._artxJQueryBackup) jQuery = document._artxJQueryBackup;</script>
    <script src="<?php echo $templateUrl; ?>/script.responsive.js"></script>
</head>
<body>

<div id="kiwi-main">
    <div id="kiwi-hmenu-bg" class="kiwi-bar kiwi-nav clearfix">
    </div>
    <div class="kiwi-sheet clearfix">
<header class="kiwi-header clearfix"><?php echo $view->position('position-30', 'kiwi-nostyle'); ?>


    <div class="kiwi-shapes">

            </div>
<h1 class="kiwi-headline" data-left="89.51%">
    <a href="<?php echo $document->baseurl; ?>/"><?php echo $this->params->get('siteTitle'); ?></a>
</h1>
<h2 class="kiwi-slogan" data-left="83.56%"><?php echo $this->params->get('siteSlogan'); ?></h2>




<?php if ($view->containsModules('position-1', 'position-28', 'position-29')) : ?>
<nav class="kiwi-nav clearfix">
    <div class="kiwi-nav-inner">
    
<?php if ($view->containsModules('position-28')) : ?>
<div class="kiwi-hmenu-extra1"><?php echo $view->position('position-28'); ?></div>
<?php endif; ?>
<?php if ($view->containsModules('position-29')) : ?>
<div class="kiwi-hmenu-extra2"><?php echo $view->position('position-29'); ?></div>
<?php endif; ?>
<?php echo $view->position('position-1'); ?>
 
        </div>
    </nav>
<?php endif; ?>

                    
</header>
<?php echo $view->position('position-15', 'kiwi-nostyle'); ?>
<?php echo $view->positions(array('position-16' => 33, 'position-17' => 33, 'position-18' => 34), 'kiwi-block'); ?>
<div class="kiwi-layout-wrapper clearfix">
                <div class="kiwi-content-layout">
                    <div class="kiwi-content-layout-row">
                        <div class="kiwi-layout-cell kiwi-content clearfix">
<?php
  echo $view->position('position-19', 'kiwi-nostyle');
  if ($view->containsModules('position-2'))
    echo artxPost($view->position('position-2'));
  echo $view->positions(array('position-20' => 50, 'position-21' => 50), 'kiwi-article');
  echo $view->position('position-12', 'kiwi-nostyle');
  echo artxPost(array('content' => '<jdoc:include type="message" />', 'classes' => ' kiwi-messages'));
  echo '<jdoc:include type="component" />';
  echo $view->position('position-22', 'kiwi-nostyle');
  echo $view->positions(array('position-23' => 50, 'position-24' => 50), 'kiwi-article');
  echo $view->position('position-25', 'kiwi-nostyle');
?>



                        </div>
                        <?php if ($view->containsModules('position-7', 'position-4', 'position-5')) : ?>
<div class="kiwi-layout-cell kiwi-sidebar1 clearfix">
<?php echo $view->position('position-7', 'kiwi-block'); ?>
<?php echo $view->position('position-4', 'kiwi-block'); ?>
<?php echo $view->position('position-5', 'kiwi-block'); ?>




                        </div>
<?php endif; ?>

                    </div>
                </div>
            </div>
<?php echo $view->positions(array('position-9' => 33, 'position-10' => 33, 'position-11' => 34), 'kiwi-block'); ?>
<?php echo $view->position('position-26', 'kiwi-nostyle'); ?>

<footer class="kiwi-footer clearfix">
<?php if ($view->containsModules('position-27')) : ?>
    <?php echo $view->position('position-27', 'kiwi-nostyle'); ?>
<?php else: ?>
<p><br></p>
<p><br></p>
<?php endif; ?>
</footer>

    </div>
    <p class="kiwi-page-footer">
        <span id="kiwi-footnote-links">Designed by <a href="http://www.kiwitemplates.com/" target="_blank">KiwiTemplates.com</a>.</span>
    </p>
</div>



<?php echo $view->position('debug'); ?>
</body>
</html>